Uses of Enum
org.apache.drill.exec.planner.PlannerPhase
Packages that use PlannerPhase
Package
Description
-
Uses of PlannerPhase in org.apache.drill.exec.planner
Methods in org.apache.drill.exec.planner that return PlannerPhaseModifier and TypeMethodDescriptionstatic PlannerPhaseReturns the enum constant of this type with the specified name.static PlannerPhase[]PlannerPhase.values()Returns an array containing the constants of this enum type, in the order they are declared. -
Uses of PlannerPhase in org.apache.drill.exec.planner.sql.handlers
Methods in org.apache.drill.exec.planner.sql.handlers with parameters of type PlannerPhaseModifier and TypeMethodDescriptionorg.apache.calcite.tools.RuleSetSqlHandlerConfig.getRules(PlannerPhase phase, org.apache.calcite.rel.RelNode input) protected voidDefaultSqlHandler.log(PlannerType plannerType, PlannerPhase phase, org.apache.calcite.rel.RelNode node, org.slf4j.Logger logger, com.google.common.base.Stopwatch watch) protected org.apache.calcite.rel.RelNodeDefaultSqlHandler.transform(PlannerType plannerType, PlannerPhase phase, org.apache.calcite.rel.RelNode input, org.apache.calcite.plan.RelTraitSet targetTraits) Transform RelNode to a new RelNode, targeting the provided set of traits.protected org.apache.calcite.rel.RelNodeDefaultSqlHandler.transform(PlannerType plannerType, PlannerPhase phase, org.apache.calcite.rel.RelNode input, org.apache.calcite.plan.RelTraitSet targetTraits, boolean log) Transform RelNode to a new RelNode, targeting the provided set of traits. -
Uses of PlannerPhase in org.apache.drill.exec.store
Methods in org.apache.drill.exec.store with parameters of type PlannerPhaseModifier and TypeMethodDescriptiondefault Set<? extends org.apache.calcite.plan.RelOptRule> StoragePlugin.getOptimizerRules(OptimizerRulesContext optimizerContext, PlannerPhase phase) An implementation of this method will return one or more specialized rules that Drill query optimizer can leverage in physical space. -
Uses of PlannerPhase in org.apache.drill.exec.store.base.filter
Methods in org.apache.drill.exec.store.base.filter with parameters of type PlannerPhaseModifier and TypeMethodDescriptionstatic booleanFilterPushDownUtils.isFilterPushDownPhase(PlannerPhase phase) Filter push-down is best done during logical planning so that the result can influence parallelization in the physical phase. -
Uses of PlannerPhase in org.apache.drill.exec.store.dfs
Methods in org.apache.drill.exec.store.dfs with parameters of type PlannerPhaseModifier and TypeMethodDescriptionSet<? extends org.apache.calcite.plan.RelOptRule> FileSystemPlugin.getOptimizerRules(OptimizerRulesContext optimizerContext, PlannerPhase phase) default Set<? extends org.apache.calcite.plan.RelOptRule> FormatPlugin.getOptimizerRules(PlannerPhase phase) -
Uses of PlannerPhase in org.apache.drill.exec.store.ischema
Methods in org.apache.drill.exec.store.ischema with parameters of type PlannerPhaseModifier and TypeMethodDescriptionInfoSchemaStoragePlugin.getOptimizerRules(OptimizerRulesContext optimizerRulesContext, PlannerPhase phase)