Uses of Class
org.apache.drill.exec.server.DrillbitContext
Packages that use DrillbitContext
Package
Description
Defines a mock data source which generates dummy test data for use
in testing.
Provides resource management and queuing support for the Drill foreman.
-
Uses of DrillbitContext in org.apache.drill.exec.alias
Constructors in org.apache.drill.exec.alias with parameters of type DrillbitContextModifierConstructorDescriptionAliasRegistryProvider(DrillbitContext context) PersistentAliasRegistry(DrillbitContext context, String registryPath) -
Uses of DrillbitContext in org.apache.drill.exec.oauth
Constructors in org.apache.drill.exec.oauth with parameters of type DrillbitContextModifierConstructorDescriptionOAuthTokenProvider(DrillbitContext context) PersistentTokenRegistry(DrillbitContext context, String registryPath) -
Uses of DrillbitContext in org.apache.drill.exec.ops
Methods in org.apache.drill.exec.ops that return DrillbitContextModifier and TypeMethodDescriptionFragmentContextImpl.getDrillbitContext()FragmentContextInterface.getDrillbitContext()Drillbit context.QueryContext.getDrillbitContext()UdfUtilities.getDrillbitContext()The Drillbit context allows UDFs to view storage information and other pieces of information about the running system.Constructors in org.apache.drill.exec.ops with parameters of type DrillbitContextModifierConstructorDescriptionFragmentContextImpl(DrillbitContext dbContext, BitControl.PlanFragment fragment, FunctionImplementationRegistry funcRegistry) Create a FragmentContext instance for non-root fragment.FragmentContextImpl(DrillbitContext dbContext, BitControl.PlanFragment fragment, QueryContext queryContext, UserClientConnection connection, FunctionImplementationRegistry funcRegistry) Create a FragmentContext instance for root fragment.FragmentContextImpl(DrillbitContext dbContext, BitControl.PlanFragment fragment, UserClientConnection connection, FunctionImplementationRegistry funcRegistry) TODO: Remove this constructor when removing the SimpleRootExec (DRILL-2097).QueryContext(UserSession session, DrillbitContext drillbitContext, UserBitShared.QueryId queryId) -
Uses of DrillbitContext in org.apache.drill.exec.server
Methods in org.apache.drill.exec.server that return DrillbitContext -
Uses of DrillbitContext in org.apache.drill.exec.server.rest.auth
Methods in org.apache.drill.exec.server.rest.auth with parameters of type DrillbitContextModifier and TypeMethodDescriptionabstract voidDrillHttpConstraintSecurityHandler.doSetup(DrillbitContext dbContext) voidFormSecurityHandler.doSetup(DrillbitContext dbContext) voidHttpBasicAuthSecurityHandler.doSetup(DrillbitContext dbContext) voidSpnegoSecurityHandler.doSetup(DrillbitContext dbContext) protected voidDrillHttpConstraintSecurityHandler.requireAuthProvider(DrillbitContext dbContext, String name) Constructors in org.apache.drill.exec.server.rest.auth with parameters of type DrillbitContextModifierConstructorDescriptionDrillHttpSecurityHandlerProvider(DrillConfig config, DrillbitContext drillContext) DrillRestLoginService(DrillbitContext drillbitContext) DrillSpnegoLoginService(DrillbitContext drillBitContext) -
Uses of DrillbitContext in org.apache.drill.exec.store
Fields in org.apache.drill.exec.store declared as DrillbitContextMethods in org.apache.drill.exec.store that return DrillbitContextModifier and TypeMethodDescriptionDrillbitPluginRegistryContext.drillbitContext()PluginRegistryContext.drillbitContext()AbstractStoragePlugin.getContext()Constructors in org.apache.drill.exec.store with parameters of type DrillbitContextModifierConstructorDescriptionprotectedAbstractStoragePlugin(DrillbitContext inContext, String inName) DrillbitPluginRegistryContext(DrillbitContext drillbitContext) SchemaTreeProvider(DrillbitContext dContext) StoragePluginRegistryImpl(DrillbitContext context) StoragePluginStoreImpl(DrillbitContext context) -
Uses of DrillbitContext in org.apache.drill.exec.store.avro
Constructors in org.apache.drill.exec.store.avro with parameters of type DrillbitContextModifierConstructorDescriptionAvroFormatPlugin(String name, DrillbitContext context, org.apache.hadoop.conf.Configuration fsConf, StoragePluginConfig storageConfig, AvroFormatConfig formatConfig) -
Uses of DrillbitContext in org.apache.drill.exec.store.dfs
Methods in org.apache.drill.exec.store.dfs that return DrillbitContextMethods in org.apache.drill.exec.store.dfs with parameters of type DrillbitContextModifier and TypeMethodDescriptionprotected FormatCreatorFileSystemPlugin.newFormatCreator(FileSystemConfig config, DrillbitContext context, org.apache.hadoop.conf.Configuration fsConf) Creates a new FormatCreator instance.Constructors in org.apache.drill.exec.store.dfs with parameters of type DrillbitContextModifierConstructorDescriptionFileSystemPlugin(FileSystemConfig config, DrillbitContext context, String name) -
Uses of DrillbitContext in org.apache.drill.exec.store.dfs.easy
Methods in org.apache.drill.exec.store.dfs.easy that return DrillbitContextConstructors in org.apache.drill.exec.store.dfs.easy with parameters of type DrillbitContextModifierConstructorDescriptionprotectedEasyFormatPlugin(String name, DrillbitContext context, org.apache.hadoop.conf.Configuration fsConf, StoragePluginConfig storageConfig, T formatConfig, boolean readable, boolean writable, boolean blockSplittable, boolean compressible, List<String> extensions, String defaultName) Legacy constructor.protectedEasyFormatPlugin(String name, EasyFormatPlugin.EasyFormatConfig config, DrillbitContext context, StoragePluginConfig storageConfig, T formatConfig) Revised constructor in which settings are gathered into a configuration object. -
Uses of DrillbitContext in org.apache.drill.exec.store.easy.json
Constructors in org.apache.drill.exec.store.easy.json with parameters of type DrillbitContextModifierConstructorDescriptionJSONFormatPlugin(String name, DrillbitContext context, org.apache.hadoop.conf.Configuration fsConf, StoragePluginConfig storageConfig) JSONFormatPlugin(String name, DrillbitContext context, org.apache.hadoop.conf.Configuration fsConf, StoragePluginConfig config, JSONFormatConfig formatPluginConfig) -
Uses of DrillbitContext in org.apache.drill.exec.store.easy.sequencefile
Constructors in org.apache.drill.exec.store.easy.sequencefile with parameters of type DrillbitContextModifierConstructorDescriptionSequenceFileFormatPlugin(String name, DrillbitContext context, org.apache.hadoop.conf.Configuration fsConf, StoragePluginConfig storageConfig, SequenceFileFormatConfig formatConfig) -
Uses of DrillbitContext in org.apache.drill.exec.store.easy.text
Constructors in org.apache.drill.exec.store.easy.text with parameters of type DrillbitContextModifierConstructorDescriptionTextFormatPlugin(String name, DrillbitContext context, org.apache.hadoop.conf.Configuration fsConf, StoragePluginConfig config, TextFormatConfig formatPluginConfig) -
Uses of DrillbitContext in org.apache.drill.exec.store.ischema
Constructors in org.apache.drill.exec.store.ischema with parameters of type DrillbitContextModifierConstructorDescriptionInfoSchemaStoragePlugin(DrillbitContext context) InfoSchemaStoragePlugin(InfoSchemaConfig config, DrillbitContext context, String name) -
Uses of DrillbitContext in org.apache.drill.exec.store.mock
Constructors in org.apache.drill.exec.store.mock with parameters of type DrillbitContextModifierConstructorDescriptionMockBreakageStorage(MockBreakageStorage.MockBreakageStorageEngineConfig configuration, DrillbitContext context, String name) MockStorageEngine(MockStorageEngineConfig configuration, DrillbitContext context, String name) -
Uses of DrillbitContext in org.apache.drill.exec.store.parquet
Methods in org.apache.drill.exec.store.parquet that return DrillbitContextConstructors in org.apache.drill.exec.store.parquet with parameters of type DrillbitContextModifierConstructorDescriptionParquetFormatPlugin(String name, DrillbitContext context, org.apache.hadoop.conf.Configuration fsConf, StoragePluginConfig storageConfig) ParquetFormatPlugin(String name, DrillbitContext context, org.apache.hadoop.conf.Configuration fsConf, StoragePluginConfig storageConfig, ParquetFormatConfig formatConfig) -
Uses of DrillbitContext in org.apache.drill.exec.store.sys
Constructors in org.apache.drill.exec.store.sys with parameters of type DrillbitContextModifierConstructorDescriptionSystemTablePlugin(DrillbitContext context) SystemTablePlugin(SystemTablePluginConfig config, DrillbitContext context, String name) -
Uses of DrillbitContext in org.apache.drill.exec.work
Methods in org.apache.drill.exec.work that return DrillbitContext -
Uses of DrillbitContext in org.apache.drill.exec.work.batch
Methods in org.apache.drill.exec.work.batch with parameters of type DrillbitContextModifier and TypeMethodDescriptionvoidControlMessageHandler.startNewFragment(BitControl.PlanFragment fragment, DrillbitContext drillbitContext) Start a new fragment on this node. -
Uses of DrillbitContext in org.apache.drill.exec.work.filter
Constructors in org.apache.drill.exec.work.filter with parameters of type DrillbitContextModifierConstructorDescriptionRuntimeFilterRouter(QueryWorkUnit workUnit, DrillbitContext drillbitContext) This class maintains context for the runtime join push down's filter management.RuntimeFilterSink(DrillbitContext drillbitContext, SendingAccountor sendingAccountor) -
Uses of DrillbitContext in org.apache.drill.exec.work.foreman
Constructors in org.apache.drill.exec.work.foreman with parameters of type DrillbitContextModifierConstructorDescriptionForeman(WorkManager.WorkerBee bee, DrillbitContext drillbitContext, UserClientConnection connection, UserBitShared.QueryId queryId, UserProtos.RunQuery queryRequest) Constructor.FragmentsRunner(WorkManager.WorkerBee bee, UserClientConnection initiatingClient, DrillbitContext drillbitContext, Foreman foreman) QueryStateProcessor(String queryIdString, QueryManager queryManager, DrillbitContext drillbitContext, Foreman.ForemanResult foremanResult) -
Uses of DrillbitContext in org.apache.drill.exec.work.foreman.rm
Fields in org.apache.drill.exec.work.foreman.rm declared as DrillbitContextConstructors in org.apache.drill.exec.work.foreman.rm with parameters of type DrillbitContextModifierConstructorDescriptionAbstractResourceManager(DrillbitContext context) DistributedQueryQueue(DrillbitContext context, DistributedQueryQueue.StatusAdapter adapter) DynamicResourceManager(DrillbitContext context) EmbeddedQueryQueue(DrillbitContext context) ResourceManagerBuilder(DrillbitContext context) ThrottledResourceManager(DrillbitContext drillbitContext, QueryQueue queue) -
Uses of DrillbitContext in org.apache.drill.exec.work.metadata
Methods in org.apache.drill.exec.work.metadata with parameters of type DrillbitContextModifier and TypeMethodDescriptionstatic RunnableMetadataProvider.catalogs(UserSession session, DrillbitContext dContext, UserProtos.GetCatalogsReq req, ResponseSender responseSender) static RunnableMetadataProvider.columns(UserSession session, DrillbitContext dContext, UserProtos.GetColumnsReq req, ResponseSender responseSender) static RunnableMetadataProvider.schemas(UserSession session, DrillbitContext dContext, UserProtos.GetSchemasReq req, ResponseSender responseSender) static RunnableMetadataProvider.tables(UserSession session, DrillbitContext dContext, UserProtos.GetTablesReq req, ResponseSender responseSender) Constructors in org.apache.drill.exec.work.metadata with parameters of type DrillbitContextModifierConstructorDescriptionServerMetaWorker(UserSession session, DrillbitContext context, UserProtos.GetServerMetaReq req, ResponseSender responseSender) -
Uses of DrillbitContext in org.apache.drill.exec.work.user
Methods in org.apache.drill.exec.work.user with parameters of type DrillbitContextModifier and TypeMethodDescriptionPlanSplitter.planFragments(DrillbitContext dContext, UserBitShared.QueryId queryId, UserProtos.GetQueryPlanFragments req, UserClientConnection connection) Method to plan the query and return list of fragments it will return query plan "as is" or split plans based on the req setting: split_plan